==> xcfa_3.4.9.orig.tar.gz: xcfa-3.4.9/src/win_play.h <==
 /*
 * file      : win_play.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __win_play_h__
#define __win_play_h__ 1

#include "player.h"

typedef struct {
	GtkWidget	*AdrWin;
	GtkObject	*AdrAdjustAllFile;
	GtkWidget	*AdrHscaleAllFile;
	GtkWidget	*AdrLabelNameFile;
	GtkWidget	*AdrStatusBar;
} VAR_LECTURE;

extern VAR_LECTURE VarLecture;


gboolean WinPlay_wind_lecture_delete_event (void);
gboolean WinPlay_wind_lecture_destroy_event (void);
void     WinPlay_button_lecture_clicked (GtkButton *button);
void     WinPlay_hbox_lecture_realize (GtkWidget *widget);
void     WinPlay_Open (LIST_PLAY_FROM ListPlayFrom, gchar *From, gchar *NameFile);
void     WinPlay_set_label_namefile (LIST_PLAY_FROM ListPlayFrom, gchar *From, gchar *NameFile);
gboolean WinPlay_IsOpen (void);
void     WinPlay_puts_statusbar (gchar *mess_label_status);
void     WinPlay_set_value_time (gdouble value);
gboolean WinPlay_Is_Ok (void);
void     WinPlay_after_end (void);


#endif

==> xcfa_3.7.3.orig.tar.gz: xcfa-3.7.3/src/win_play.h <==
 /*
 * file      : win_play.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003 - 2010 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __win_play_h__
#define __win_play_h__ 1

#include "mplayer.h"

typedef struct {
	GtkWidget	*AdrWin;
	gboolean	 Bool;
	GtkObject	*AdrAdjustAllFile;
	GtkWidget	*AdrHscaleAllFile;
	GtkWidget	*AdrLabelNameFile;
	GtkWidget	*AdrStatusBar;
} VAR_LECTURE;

extern VAR_LECTURE VarLecture;


gboolean WinPlay_wind_lecture_delete_event (void);
gboolean WinPlay_wind_lecture_destroy_event (void);
void     WinPlay_button_lecture_clicked (GtkButton *button);
void     WinPlay_hbox_lecture_realize (GtkWidget *widget);
void     WinPlay_Open (LIST_MPLAYER_FROM ListPlayFrom, gchar *From, gchar *NameFile);
void     WinPlay_set_label_namefile (LIST_MPLAYER_FROM ListPlayFrom, gchar *From, gchar *NameFile);
gboolean WinPlay_IsOpen (void);
void     WinPlay_puts_statusbar (gchar *mess_label_status);
void     WinPlay_set_value_time (gdouble value);
gboolean WinPlay_Is_Ok (void);
void     WinPlay_after_end (void);


#endif
